@@ -31,6 +31,21 @@ CREATE TABLE acl_sync (
     change_time timestamp(0) NOT NULL
 );
 -- ----------------------------------------------------------
+--  create table activity
+-- ----------------------------------------------------------
+CREATE TABLE activity (
+    id serial NOT NULL,
+    user_id INTEGER NOT NULL,
+    activity_type VARCHAR (200) NOT NULL,
+    activity_title VARCHAR (255) NOT NULL,
+    activity_text TEXT NULL,
+    activity_state VARCHAR (255) NULL,
+    activity_link VARCHAR (255) NULL,
+    create_time timestamp(0) NOT NULL,
+    create_by INTEGER NOT NULL,
+    PRIMARY KEY(id)
+);
+-- ----------------------------------------------------------
 --  create table acl_ticket_attribute_relations
 -- ----------------------------------------------------------
 CREATE TABLE acl_ticket_attribute_relations (
@@ -510,6 +525,7 @@ CREATE TABLE ticket_priority (
     id serial NOT NULL,
     name VARCHAR (200) NOT NULL,
     valid_id SMALLINT NOT NULL,
+    color VARCHAR (25) NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by INTEGER NOT NULL,
     change_time timestamp(0) NOT NULL,
@@ -554,6 +570,7 @@ CREATE TABLE ticket_state (
     comments VARCHAR (250) NULL,
     type_id SMALLINT NOT NULL,
     valid_id SMALLINT NOT NULL,
+    color VARCHAR (25) NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by INTEGER NOT NULL,
     change_time timestamp(0) NOT NULL,
@@ -2650,21 +2667,6 @@ END IF;
 END$$;
 ;
 -- ----------------------------------------------------------
---  create table cloud_service_config
--- ----------------------------------------------------------
-CREATE TABLE cloud_service_config (
-    id serial NOT NULL,
-    name VARCHAR (200) NOT NULL,
-    config TEXT NOT NULL,
-    valid_id SMALLINT NOT NULL,
-    create_time timestamp(0) NOT NULL,
-    create_by INTEGER NOT NULL,
-    change_time timestamp(0) NOT NULL,
-    change_by INTEGER NOT NULL,
-    PRIMARY KEY(id),
-    CONSTRAINT cloud_service_config_name UNIQUE (name)
-);
--- ----------------------------------------------------------
 --  create table sysconfig_default
 -- ----------------------------------------------------------
 CREATE TABLE sysconfig_default (
@@ -2854,14 +2856,16 @@ CREATE TABLE calendar_appointment (
 -- ----------------------------------------------------------
 CREATE TABLE calendar_appointment_plugin (
     id serial NOT NULL,
-    appointment_id SMALLINT NOT NULL,
+    dbcrud_uuid VARCHAR (36) NULL,
+    appointment_id BIGINT NOT NULL,
     plugin_key VARCHAR (1000) NOT NULL,
     config VARCHAR NULL,
     create_time timestamp(0) NOT NULL,
     create_by INTEGER NOT NULL,
     change_time timestamp(0) NOT NULL,
     change_by INTEGER NOT NULL,
-    PRIMARY KEY(id)
+    PRIMARY KEY(id),
+    CONSTRAINT calendar_appointment_plugin_uuid UNIQUE (dbcrud_uuid)
 );
 -- ----------------------------------------------------------
 --  create table calendar_appointment_ticket
@@ -3142,10 +3146,10 @@ CREATE TABLE smime_keys (
     key_hash VARCHAR (8) NOT NULL,
     key_type VARCHAR (255) NOT NULL,
     file_name VARCHAR (255) NOT NULL,
-    email_address VARCHAR (255) NULL,
+    email_address VARCHAR NULL,
     expiration_date timestamp(0) NULL,
     fingerprint VARCHAR (59) NULL,
-    subject VARCHAR (255) NULL,
+    subject VARCHAR NULL,
     create_time timestamp(0) NULL,
     change_time timestamp(0) NULL,
     create_by INTEGER NULL,
@@ -3190,6 +3194,7 @@ END$$;
 -- ----------------------------------------------------------
 CREATE TABLE oauth2_token_config (
     id serial NOT NULL,
+    dbcrud_uuid VARCHAR (36) NULL,
     name VARCHAR (250) NOT NULL,
     config VARCHAR NOT NULL,
     valid_id SMALLINT NOT NULL,
@@ -3198,13 +3203,15 @@ CREATE TABLE oauth2_token_config (
     change_time timestamp(0) NOT NULL,
     change_by INTEGER NOT NULL,
     PRIMARY KEY(id),
-    CONSTRAINT oauth2_token_config_name UNIQUE (name)
+    CONSTRAINT oauth2_token_config_name UNIQUE (name),
+    CONSTRAINT oauth2_token_config_uuid UNIQUE (dbcrud_uuid)
 );
 -- ----------------------------------------------------------
 --  create table oauth2_token
 -- ----------------------------------------------------------
 CREATE TABLE oauth2_token (
     id serial NOT NULL,
+    dbcrud_uuid VARCHAR (36) NULL,
     token_config_id INTEGER NOT NULL,
     authorization_code VARCHAR NULL,
     token VARCHAR NULL,
@@ -3219,7 +3226,8 @@ CREATE TABLE oauth2_token (
     change_time timestamp(0) NOT NULL,
     change_by INTEGER NOT NULL,
     PRIMARY KEY(id),
-    CONSTRAINT oauth2_token_config_id UNIQUE (token_config_id)
+    CONSTRAINT oauth2_token_config_id UNIQUE (token_config_id),
+    CONSTRAINT oauth2_token_uuid UNIQUE (dbcrud_uuid)
 );
 -- ----------------------------------------------------------
 --  create table mention
